@@ -488,7 +488,7 @@ main (int argc, char *argv[])
 	 */
 	prompt = get_passwords_required (data, hints, &need_password, &need_group_password);
 	if (!prompt)
-		prompt = g_strdup_printf (_("You need to authenticate to access the Virtual Private Network '%s'."), vpn_name);
+		prompt = g_strdup_printf (_("You need to authenticate to access the Virtual Private Network “%s”."), vpn_name);
 
 	/* Exit early if we don't need any passwords */
 	if (!need_password && !need_group_password)
